function [hoursprof lfpprof nhoursprof nlfpprof monthlylfp maxhours minhours] = CanadaSimOLG2(hbar,mu,e0,e1,gamma,tau,taun,taun2,taulength,genspermonth)
%CanadaSimOLG2: Canada SSP Sim for genspermonth * 60 * 12 generations.
%Computes optimum for each generation and adds across generations
% Tax rate is initially tau. At time zero, changes to taun for taulength.
% At time taulength changes permanently to taun2

%Version 2: Only look at individuals in the first half of life (16-46).
%This requires changing the denominator when adding up. It also requries
%zeroing the hours profile in second half of life. To save computing time,
%we do not compute the response of individuals who are in the second half
%of their lives when the change occurs.

%To do this, for given hbar, e0, e1, gamma, and mu computes asset profile
%and then solves IcelandSim forward for each generation. Then adds across generations
%to get path of LFP and overall hours profile over time with and without
%the tax change.

%Also bins each generation monthly to reflect data that asks whether an
%individual has been employed in the last month

gens=genspermonth*60*12;
step=1/gens;
gens=gens+1;
time=0:step:1;

%First simulate the model for the given hbar, e0, e1, gamma, and mu to get
%the asset profile
[ohprof s]=RWSim(hbar,mu,e0,e1,gamma,tau,gens);
ohprof(time>.5)=0; %only first half of life.
olprof =(ohprof>0);

%Then simulate the model with tau2n to get the hours profile for
%generations that enter after the reform (e for entering generations)
ehprof=RWSim(hbar,mu,e0,e1,gamma,taun2,gens);
ehprof(time>.5)=0;
elprof=(ehprof>0);

hoursprof=zeros(1,gens);
lfpprof=zeros(1,gens);
%compute hoursprof and lfpprof with no tax change for overlapping generations
for(i=1:gens)
    hoursprof=hoursprof+1/(gens/2)+1*[ohprof(i:gens) ohprof(1:i-1)];
    lfpprof=lfpprof+1/(gens/2)*[olprof(i:gens) olprof(1:i-1)];
end

%Loop through each generation and compute hours and LFP with tax = taun for
%taulength and then return to taun2 afterwards
nhoursprof=zeros(1,gens); %aggregate hours profile across generations
nlfpprof=zeros(1,gens); %aggregate lfp profile across generations
monthlylfp=zeros(120*12,2); %weekly lfp across generations
monthlylfp(:,1)=[-60:(1/12):(3119/52)]'; %first column is dates
monthly=zeros(120*12,1);
maxhours=0;minhours=1;
for(i=1:gens)
    t0=time(i); % age at which generation reoptimizes (initial tax change)
    t1=t0+taulength; %age at which tax reverts
    %run the simulation for outgoing generation age t when tax change occurs
    %since we are only going to look at generations in the first half of
    %life, if t0>.5 we will just get zeros and we can save computing time
    %by not running the simulation
    [nhprof nc E0 R0 E1 R1 error]=IcelandSim(hbar,mu,e0,e1,gamma,taun,taun2,t0,t1,s(i),gens);
    if(error==1)
       error=1
       break;
    end
    nhprof(time>.5)=0;
    nlprof=(nhprof>0); %lfpprof
    maxhours=max(maxhours,max(nhprof));
    if(max(nhprof)>0)
        minhours=min(minhours,min(nhprof(nhprof>0)));
    end
    if(1-t0<taulength) %if you don't see the tax change back during your life, the incoming generation has the low tax for some amount of time
       [nhprof2 nc E0 R0 E1 R1 error]=IcelandSim(hbar,mu,e0,e1,gamma,taun,taun2,0,taulength-(1-t0),s(i),gens);
       if(error==1)
           error=1
           break;
       end
       nhprof2(time>.5)=0;
       nlprof2=(nhprof2>0);
       maxhours=max(maxhours,max(nhprof2));
       if(max(nhprof2)>0)
            minhours=min(minhours,min(nhprof2(nhprof2>0)));
       end
        
       %add generation and generation that replaces it on to aggregae
       %hours profile (weight generation 1/1001)
       nhoursprof=nhoursprof+(1/(gens/2)*[nhprof(i:gens) nhprof2(1:i-1)]);
       nlfpprof=nlfpprof+(1/(gens/2)*[nlprof(i:gens) nlprof2(1:i-1)]);
       
       %build monthly bins
       fulllfpprof=[olprof(i:gens) olprof(1:i-1) nlprof(i:gens) nlprof2(1:i-1)];
       for(j=0:(12*120-1))
           monthly(j+1)=max(fulllfpprof((j*genspermonth+1):((j+1)*genspermonth)));
       end
       monthlylfp(:,2)=monthlylfp(:,2)+1/(gens/2)*monthly;
    else
       %add generation and generation that replaces it on to aggregate
       %hours profile (weight generation 1/gens)
       nhoursprof=nhoursprof+(1/(gens/2)*[nhprof(i:gens) ehprof(1:i-1)]);
       nlfpprof=nlfpprof+(1/(gens/2)*[nlprof(i:gens) elprof(1:i-1)]);
       
       %build monthly bins
        fulllfpprof=[olprof(i:gens) olprof(1:i-1) nlprof(i:gens) elprof(1:i-1)];
        for(j=0:(12*120-1))
            monthly(j+1)=max(fulllfpprof((j*genspermonth+1):((j+1)*genspermonth)));
        end
        monthlylfp(:,2)=monthlylfp(:,2)+1/(gens/2)*monthly;
    end
end
end

